@@ -4,10 +4,10 @@ import pyperclip
 from .gui_components.abstract_ai_gui_shared import get_total_layout,instructions_keys, all_token_keys, test_options_keys
 from .gui_components.generate_readme import read_me_window
 from .gui_components.abstract_ai_gui_navigation import AbstractNavigationManager
-from .gpt_classes import ApiManager,InstructionManager,ResponseManager,PromptManager,ModelManager
-from .specializations import generate_query_from_recent_response,FileCollator,read_from_file_with_multiple_encodings,get_instruction_from_tableName,search_multiple_fields
+from .gpt_classes import ApiManager,InstructionManager,ResponseManager,PromptManager,ModelManager\
+from .specializations import FileCollator,read_from_file_with_multiple_encodings
 from abstract_webtools import UrlManager, SafeRequest, url_grabber_component
-import PySimpleGUIWeb as sg
+
 
 from abstract_gui import (
     get_event_key_js,
@@ -478,11 +478,9 @@ below is an example of the expected json dictionary response format, with the de
         elif self.event in ['-REDO_CHUNKS-',
                             '-ADD_URL_TO_CHUNK-',
                             '-ADD_FILE_TO_CHUNK-',
-                            '-ADD_QUERY_TO_CHUNK-',
                             '-COMPLETION_PERCENTAGE-',
                             '-PROMPT_PERCENTAGE-'] or self.script_event_js['found'] in ['-FILE_TEXT-',
                                                                                         '-ADD_FILE_TO_CHUNK-',
-                                                                                        '-ADD_QUERY_TO_CHUNK-',
                                                                                         '-ADD_URL_TO_CHUNK-']:
             data=None
             if self.event == '-CLEAR_CHUNKS-':
@@ -507,18 +505,15 @@ below is an example of the expected json dictionary response format, with the de
 
             elif self.event == '-REDO_CHUNKS-':
                 data = self.history_mgr.redo(self.chunk_history_name)
+                
             elif self.event == '-ADD_URL_TO_CHUNK-':
                 self.chunk_title=self.window_mgr.get_values()[text_to_key('-CHUNK_TITLE-',section='url')]
                 data = self.add_to_chunk(self.window_mgr.get_values()['-URL_TEXT-'])
                 self.chunk_type=self.url_chunk_type
                 
             elif self.script_event_js['found']=='-ADD_FILE_TO_CHUNK-':
-                self.chunk_title=self.window_mgr.get_values()[text_to_key('-CHUNK_TITLE-',section=self.script_event_js['section'])]
-                data = self.add_to_chunk(self.window_mgr.get_values()[text_to_key('-FILE_TEXT-',section=self.script_event_js['section'])])
-                if self.script_event_js['section'].lower() == 'database':
-                    spec_num = self.get_spec_section_number_display('request')
-                    self.instruction_data_list[spec_num]['bool_values']['database_query']=True
-                    self.update_bool_instructions()
+                self.chunk_title=self.window_mgr.get_values()[text_to_key('-CHUNK_TITLE-',section='files')]
+                data = self.add_to_chunk(self.window_mgr.get_values()[self.script_event_js['-FILE_TEXT-']])
                 self.chunk_type='CODE'
             self.update_prompt_data(data)
 
@@ -836,7 +831,7 @@ below is an example of the expected json dictionary response format, with the de
             return False
         return True
     
-    def get_output_response(self,model:str="None",title:str="None",request:str="None",response:str="None",output_files:str="None")->str:
+    def get_output_response(self,model:str="None",title:str="None",request:str="None",response:str="None")->str:
         """
         A helper method that formats the output string of a response in a clear and readable manner.
         It includes information about the model, title, user request, and AI response.
@@ -845,8 +840,7 @@ below is an example of the expected json dictionary response format, with the de
         title = f"#TITLE#{self.get_new_line(1)}{str(title)}{self.get_new_line(2)}"
         request = f"#USER REQUEST#{self.get_new_line(1)}{str(request)}{self.get_new_line(2)}"
         response = f"#RESPONSE#{self.get_new_line(2)}{str(response)}{self.get_new_line(2)}"
-        output_files = f"#OUTPUT FILES#{self.get_new_line(1)}{str(output_files)}{self.get_new_line(2)}"
-        return f"{model}{title}{request}{response}{output_files}"
+        return f"{model}{title}{request}{response}"
     
     def update_text_with_responses(self)->None:
         """
@@ -864,7 +858,6 @@ below is an example of the expected json dictionary response format, with the de
         self.last_model =get_any_value(safe_json_loads(self.last_response),'model')
         self.unlist_self(["last_model","last_api_response","last_content"])
         self.window_mgr.update_value(key=text_to_key('title input'),value=self.last_title)
-        self.database_output_file = generate_query_from_recent_response(file_path=self.last_file_path)
         response_content = self.last_content
         if self.last_api_response:
             response_content=self.last_api_response
@@ -872,8 +865,7 @@ below is an example of the expected json dictionary response format, with the de
         self.window_mgr.update_value('-RESPONSE-',self.get_output_response(model=self.last_model,
                                                                            title=self.last_title,
                                                                            request=self.request_data_list[self.get_current_request_data()],
-                                                                           response=response_content,output_files=self.database_output_file))
-        
+                                                                           response=response_content))
     def get_current_request_data(self)->int:
         num=0
         for i,data in enumerate(self.prompt_data_list):
@@ -967,10 +959,7 @@ below is an example of the expected json dictionary response format, with the de
             if selected_files:
                 file_path = os.path.join(directory, selected_files[0])
                 event_triggered = True
-        if self.window_mgr.get_from_value(text_to_key('database query bool', section='database')):
-                contents = get_instruction_from_tableName(self.window_mgr.get_from_value(text_to_key('table configuration', section='database')))
-                self.window_mgr.update_value(key=text_to_key('-FILE_TEXT-', section='database'), value=contents)
-                self.window_mgr.update_value(key=text_to_key('-CHUNK_TITLE-', section='database'), value=self.chunk_title)
+        
         if file_path:
             if os.path.isfile(file_path):
                 try:
@@ -992,8 +981,7 @@ below is an example of the expected json dictionary response format, with the de
                     if not os.path.isfile(file_path):
                         self.browser_mgr.handle_event(self.event,self.window_mgr.get_values(),self.window)
         return event_triggered
-
-    get_instruction_from_tableName()
+    
     def update_last_response_file(self)->None:
         """
         Updates the path to the last file that recorded a response.
@@ -1099,35 +1087,6 @@ below is an example of the expected json dictionary response format, with the de
                     
             self.chunk_type="CODE"
             
-            if prompt_data:
-                self.update_prompt_data(prompt_data)
-            
-            if request_data:
-                self.update_request_data(request_data)
-        else:
-            return False
-        return True
-    def database_event_check(self)->bool:
-        """
-        Checks if the Generate README event has been triggered.
-
-        The Generate README event is triggered when a user opts to generate a README file for the prompt.
-
-        Returns:
-            bool: True if the Generate README event has been triggered, otherwise False
-        """
-        if self.event=="-GENERATE_DATABASE_QUERY-":
-            prompt_number=self.get_prompt_data_section_number()
-            prompt_data = self.prompt_data_list[prompt_number]
-            request_data = self.request_data_list[prompt_number]
-            prompt_data+='\n\n'+get_instruction_from_tableName()
-            self.update_prompt_data(prompt_data)
-            
-            contents = self.read_file_contents(file_path)  # Assuming read_file_contents is defined to handle different file types
-            contents = safe_json_loads(contents)
-
-
-            
             if prompt_data:
                 self.update_prompt_data(prompt_data)
             
