@@ -1,8 +1,8 @@
 from .gpt_classes.api_selection.ApiBuilder import ApiManager
+from .gpt_classes.file_section.JsonHandler import FileCollator,read_from_file_with_multiple_encodings
 from .gpt_classes.model_selection.ModelBuilder import ModelManager
 from .gpt_classes.prompt_selection.PromptBuilder import PromptManager
 from .gpt_classes.response_selection.ResponseBuilder import ResponseManager
 from .gpt_classes.instruction_selection.InstructionBuilder import InstructionManager
-from .gpt_classes.nogui_selection.nogui_query import nogui_setup_module
 from .specializations import *
 from .abstract_ai_gui import abstract_ai_gui
