@@ -23,7 +23,7 @@ def get_dict_from_instruction(instructions):
                 new_instructions[key] = new_instruction
     return new_instructions
 class InstructionManager:
-    def __init__(self,instructions=None,instruction_bools={})->None:
+    def __init__(self,instructions=None)->None:
         self.default_instructions = {
                     "api_response": {
                         "instruction": "Place response to prompt here.",
@@ -37,10 +37,6 @@ class InstructionManager:
                         "instruction": "Generate a short and concise title for this query, using underscores instead of spaces and avoiding special characters. The title should not exceed 200 characters to ensure compatibility with file systems.",
                         "example": "Short_Title_for_Query",
                         "default":True},
-                    "database_query":{
-                        "instruction": "the given database Schema,variables,values and function are provided in the prompt data; please derive the most appropriate inputs for a database query from the context and assertons of the request. place all inputs for the function within this respons key",
-                        "example": {"query":"""SELECT dnc_data FROM dncdata WHERE dnc_data ->> 'Data_Subscriber_First_Name' = 'Karen';"""},
-                        "default":False},
                     "notation": {
                         "instruction": "notation is a module end  functionality that allows the module, you, to to preserve relevant information or context for subsequent prompts; allowing for communication between modules throughout the query iterations. ",
                         "example": "Selecting additional responses due to insufficient completion tokens.",
@@ -68,8 +64,6 @@ class InstructionManager:
                     }
         self.instructions = [[]]
         self.default_instructions.update(get_dict_from_instruction(instructions))
-        for key,value in instruction_bools.items():
-            self.default_instructions[key]['defaut'] = value
         self.update_instructions(0,**{key:self.default_instructions[key] for key in self.default_instructions if self.default_instructions[key].get('default')})
     def get_instructions(self,instruction_number:int=None)->dict:
         if len(self.instructions)==0:
